@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2019 Alexander Mikhaylenko <exalm7659@gmail.com>
+ * Copyright (C) 2019 Alice Mikhaylenko <alicem@gnome.org>
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  */
@@ -465,11 +465,10 @@ update_orientation (AdwCarousel *self)
   set_orientable_style_classes (GTK_ORIENTABLE (self));
 }
 
-static gboolean
+static void
 scroll_timeout_cb (AdwCarousel *self)
 {
   self->can_scroll = TRUE;
-  return G_SOURCE_REMOVE;
 }
 
 static gboolean
@@ -535,7 +534,9 @@ scroll_cb (AdwCarousel              *self,
 
   self->can_scroll = FALSE;
   self->scroll_timeout_id =
-   g_timeout_add (SCROLL_TIMEOUT_DURATION, (GSourceFunc) scroll_timeout_cb, self);
+   g_timeout_add_once (SCROLL_TIMEOUT_DURATION,
+                       (GSourceOnceFunc) scroll_timeout_cb,
+                       self);
 
   return GDK_EVENT_STOP;
 }
@@ -1174,6 +1175,7 @@ adw_carousel_prepend (AdwCarousel *self,
 {
   g_return_if_fail (ADW_IS_CAROUSEL (self));
   g_return_if_fail (GTK_IS_WIDGET (widget));
+  g_return_if_fail (gtk_widget_get_parent (widget) == NULL);
 
   adw_carousel_insert (self, widget, 0);
 }
@@ -1191,6 +1193,7 @@ adw_carousel_append (AdwCarousel *self,
 {
   g_return_if_fail (ADW_IS_CAROUSEL (self));
   g_return_if_fail (GTK_IS_WIDGET (widget));
+  g_return_if_fail (gtk_widget_get_parent (widget) == NULL);
 
   adw_carousel_insert (self, widget, -1);
 }
@@ -1216,6 +1219,7 @@ adw_carousel_insert (AdwCarousel *self,
 
   g_return_if_fail (ADW_IS_CAROUSEL (self));
   g_return_if_fail (GTK_IS_WIDGET (widget));
+  g_return_if_fail (gtk_widget_get_parent (widget) == NULL);
   g_return_if_fail (position >= -1);
 
   info = g_new0 (ChildInfo, 1);
@@ -1386,7 +1390,7 @@ typedef struct {
   gboolean animate;
 } ScrollData;
 
-static gboolean
+static void
 scroll_to_idle_cb (ScrollData *data)
 {
   do_scroll_to (data->carousel, data->widget, data->animate);
@@ -1394,8 +1398,6 @@ scroll_to_idle_cb (ScrollData *data)
   g_object_unref (data->carousel);
   g_object_unref (data->widget);
   g_free (data);
-
-  return FALSE;
 }
 
 /**
@@ -1413,14 +1415,10 @@ adw_carousel_scroll_to (AdwCarousel *self,
                         GtkWidget   *widget,
                         gboolean     animate)
 {
-  ChildInfo *info;
-
   g_return_if_fail (ADW_IS_CAROUSEL (self));
   g_return_if_fail (GTK_IS_WIDGET (widget));
   g_return_if_fail (gtk_widget_get_parent (widget) == GTK_WIDGET (self));
 
-  info = find_child_info (self, widget);
-
   if (self->is_being_allocated) {
     /* 'self' is still being allocated/resized by GTK
      * async machinery (initiated from a previous adw_carousel_insert() call)
@@ -1434,7 +1432,7 @@ adw_carousel_scroll_to (AdwCarousel *self,
     data->widget = g_object_ref (widget);
     data->animate = animate;
 
-    g_idle_add (G_SOURCE_FUNC (scroll_to_idle_cb), data);
+    g_idle_add_once ((GSourceOnceFunc) scroll_to_idle_cb, data);
     return;
   }
 
