@@ -200,7 +200,10 @@ adw_squeezer_page_finalize (GObject *object)
   AdwSqueezerPage *self = ADW_SQUEEZER_PAGE (object);
 
   g_clear_object (&self->widget);
-  g_clear_weak_pointer (&self->last_focus);
+
+  if (self->last_focus)
+    g_object_remove_weak_pointer (G_OBJECT (self->last_focus),
+                                  (gpointer *) &self->last_focus);
 
   G_OBJECT_CLASS (adw_squeezer_page_parent_class)->finalize (object);
 }
@@ -215,7 +218,7 @@ adw_squeezer_page_class_init (AdwSqueezerPageClass *klass)
   object_class->finalize = adw_squeezer_page_finalize;
 
   /**
-   * AdwSqueezerPage:child:
+   * AdwSqueezerPage:child: (attributes org.gtk.Property.get=adw_squeezer_page_get_child)
    *
    * The the squeezer child to which the page belongs.
    *
@@ -227,7 +230,7 @@ adw_squeezer_page_class_init (AdwSqueezerPageClass *klass)
                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS | G_PARAM_DEPRECATED);
 
   /**
-   * AdwSqueezerPage:enabled:
+   * AdwSqueezerPage:enabled: (attributes org.gtk.Property.get=adw_squeezer_page_get_enabled org.gtk.Property.set=adw_squeezer_page_set_enabled)
    *
    * Whether the child is enabled.
    *
@@ -474,7 +477,12 @@ set_visible_child (AdwSqueezer               *self,
       gtk_widget_is_ancestor (focus, self->visible_child->widget)) {
     contains_focus = TRUE;
 
-    g_set_weak_pointer (&self->visible_child->last_focus, focus);
+    if (self->visible_child->last_focus)
+      g_object_remove_weak_pointer (G_OBJECT (self->visible_child->last_focus),
+                                    (gpointer *)&self->visible_child->last_focus);
+    self->visible_child->last_focus = focus;
+    g_object_add_weak_pointer (G_OBJECT (self->visible_child->last_focus),
+                               (gpointer *)&self->visible_child->last_focus);
   }
 
   if (self->transition_running)
@@ -1003,7 +1011,9 @@ adw_squeezer_finalize (GObject *object)
 {
   AdwSqueezer *self = ADW_SQUEEZER (object);
 
-  g_clear_weak_pointer (&self->pages);
+  if (self->pages)
+    g_object_remove_weak_pointer (G_OBJECT (self->pages),
+                                  (gpointer *) &self->pages);
 
   G_OBJECT_CLASS (adw_squeezer_parent_class)->finalize (object);
 }
@@ -1030,7 +1040,7 @@ adw_squeezer_class_init (AdwSqueezerClass *klass)
                                     "orientation");
 
   /**
-   * AdwSqueezer:visible-child:
+   * AdwSqueezer:visible-child: (attributes org.gtk.Property.get=adw_squeezer_get_visible_child)
    *
    * The currently visible child.
    *
@@ -1042,7 +1052,7 @@ adw_squeezer_class_init (AdwSqueezerClass *klass)
                          G_PARAM_READABLE | G_PARAM_STATIC_STRINGS | G_PARAM_DEPRECATED);
 
   /**
-   * AdwSqueezer:homogeneous:
+   * AdwSqueezer:homogeneous: (attributes org.gtk.Property.get=adw_squeezer_get_homogeneous org.gtk.Property.set=adw_squeezer_set_homogeneous)
    *
    * Whether all children have the same size for the opposite orientation.
    *
@@ -1058,7 +1068,7 @@ adw_squeezer_class_init (AdwSqueezerClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
 
   /**
-   * AdwSqueezer:switch-threshold-policy:
+   * AdwSqueezer:switch-threshold-policy: (attributes org.gtk.Property.get=adw_squeezer_get_switch_threshold_policy org.gtk.Property.set=adw_squeezer_set_switch_threshold_policy)
    *
    * The switch threshold policy.
    *
@@ -1080,7 +1090,7 @@ adw_squeezer_class_init (AdwSqueezerClass *klass)
                        G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
 
   /**
-   * AdwSqueezer:allow-none:
+   * AdwSqueezer:allow-none: (attributes org.gtk.Property.get=adw_squeezer_get_allow_none org.gtk.Property.set=adw_squeezer_set_allow_none)
    *
    * Whether to allow squeezing beyond the last child's minimum size.
    *
@@ -1096,7 +1106,7 @@ adw_squeezer_class_init (AdwSqueezerClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
 
   /**
-   * AdwSqueezer:transition-duration:
+   * AdwSqueezer:transition-duration: (attributes org.gtk.Property.get=adw_squeezer_get_transition_duration org.gtk.Property.set=adw_squeezer_set_transition_duration)
    *
    * The transition animation duration, in milliseconds.
    *
@@ -1108,7 +1118,7 @@ adw_squeezer_class_init (AdwSqueezerClass *klass)
                        G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
 
   /**
-   * AdwSqueezer:transition-type:
+   * AdwSqueezer:transition-type: (attributes org.gtk.Property.get=adw_squeezer_get_transition_type org.gtk.Property.set=adw_squeezer_set_transition_type)
    *
    * The type of animation used for transitions between children.
    *
@@ -1121,7 +1131,7 @@ adw_squeezer_class_init (AdwSqueezerClass *klass)
                        G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
 
   /**
-   * AdwSqueezer:transition-running:
+   * AdwSqueezer:transition-running: (attributes org.gtk.Property.get=adw_squeezer_get_transition_running)
    *
    * Whether a transition is currently running.
    *
@@ -1137,7 +1147,7 @@ adw_squeezer_class_init (AdwSqueezerClass *klass)
                           G_PARAM_READABLE | G_PARAM_STATIC_STRINGS | G_PARAM_DEPRECATED);
 
   /**
-   * AdwSqueezer:interpolate-size:
+   * AdwSqueezer:interpolate-size: (attributes org.gtk.Property.get=adw_squeezer_get_interpolate_size org.gtk.Property.set=adw_squeezer_set_interpolate_size)
    *
    * Whether the squeezer interpolates its size when changing the visible child.
    *
@@ -1154,7 +1164,7 @@ adw_squeezer_class_init (AdwSqueezerClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
 
   /**
-   * AdwSqueezer:xalign:
+   * AdwSqueezer:xalign: (attributes org.gtk.Property.get=adw_squeezer_get_xalign org.gtk.Property.set=adw_squeezer_set_xalign)
    *
    * The horizontal alignment, from 0 (start) to 1 (end).
    *
@@ -1173,7 +1183,7 @@ adw_squeezer_class_init (AdwSqueezerClass *klass)
                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
 
   /**
-   * AdwSqueezer:yalign:
+   * AdwSqueezer:yalign: (attributes org.gtk.Property.get=adw_squeezer_get_yalign org.gtk.Property.set=adw_squeezer_set_yalign)
    *
    * The vertical alignment, from 0 (top) to 1 (bottom).
    *
@@ -1192,7 +1202,7 @@ adw_squeezer_class_init (AdwSqueezerClass *klass)
                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
 
   /**
-   * AdwSqueezer:pages:
+   * AdwSqueezer:pages: (attributes org.gtk.Property.get=adw_squeezer_get_pages)
    *
    * A selection model with the squeezer's pages.
    *
@@ -1256,7 +1266,7 @@ adw_squeezer_buildable_init (GtkBuildableIface *iface)
 }
 
 /**
- * adw_squeezer_page_get_child:
+ * adw_squeezer_page_get_child: (attributes org.gtk.Method.get_property=child)
  * @self: a squeezer page
  *
  * Returns the squeezer child to which @self belongs.
@@ -1274,7 +1284,7 @@ adw_squeezer_page_get_child (AdwSqueezerPage *self)
 }
 
 /**
- * adw_squeezer_page_get_enabled:
+ * adw_squeezer_page_get_enabled: (attributes org.gtk.Method.get_property=enabled)
  * @self: a squeezer page
  *
  * Gets whether @self is enabled.
@@ -1292,7 +1302,7 @@ adw_squeezer_page_get_enabled (AdwSqueezerPage *self)
 }
 
 /**
- * adw_squeezer_page_set_enabled:
+ * adw_squeezer_page_set_enabled: (attributes org.gtk.Method.set_property=enabled)
  * @self: a squeezer page
  * @enabled: whether @self is enabled
  *
@@ -1432,7 +1442,7 @@ adw_squeezer_get_page (AdwSqueezer *self,
 }
 
 /**
- * adw_squeezer_get_visible_child:
+ * adw_squeezer_get_visible_child: (attributes org.gtk.Method.get_property=visible-child)
  * @self: a squeezer
  *
  * Gets the currently visible child of @self.
@@ -1450,7 +1460,7 @@ adw_squeezer_get_visible_child (AdwSqueezer *self)
 }
 
 /**
- * adw_squeezer_get_homogeneous:
+ * adw_squeezer_get_homogeneous: (attributes org.gtk.Method.get_property=homogeneous)
  * @self: a squeezer
  *
  * Gets whether all children have the same size for the opposite orientation.
@@ -1468,7 +1478,7 @@ adw_squeezer_get_homogeneous (AdwSqueezer *self)
 }
 
 /**
- * adw_squeezer_set_homogeneous:
+ * adw_squeezer_set_homogeneous: (attributes org.gtk.Method.set_property=homogeneous)
  * @self: a squeezer
  * @homogeneous: whether @self is homogeneous
  *
@@ -1500,13 +1510,11 @@ adw_squeezer_set_homogeneous (AdwSqueezer *self,
 }
 
 /**
- * adw_squeezer_get_switch_threshold_policy:
+ * adw_squeezer_get_switch_threshold_policy: (attributes org.gtk.Method.get_property=switch-threshold-policy)
  * @self: a squeezer
  *
  * Gets the switch threshold policy for @self.
  *
- * Returns: the fold threshold policy
- *
  * Deprecated: 1.4: See [the migration guide](migrating-to-breakpoints.html#replace-adwsqueezer)
  */
 AdwFoldThresholdPolicy
@@ -1519,7 +1527,7 @@ adw_squeezer_get_switch_threshold_policy (AdwSqueezer *self)
 
 
 /**
- * adw_squeezer_set_switch_threshold_policy:
+ * adw_squeezer_set_switch_threshold_policy: (attributes org.gtk.Method.set_property=switch-threshold-policy)
  * @self: a squeezer
  * @policy: the policy to use
  *
@@ -1554,7 +1562,7 @@ adw_squeezer_set_switch_threshold_policy (AdwSqueezer            *self,
 }
 
 /**
- * adw_squeezer_get_allow_none:
+ * adw_squeezer_get_allow_none: (attributes org.gtk.Method.get_property=allow-none)
  * @self: a squeezer
  *
  * Gets whether to allow squeezing beyond the last child's minimum size.
@@ -1572,7 +1580,7 @@ adw_squeezer_get_allow_none (AdwSqueezer *self)
 }
 
 /**
- * adw_squeezer_set_allow_none:
+ * adw_squeezer_set_allow_none: (attributes org.gtk.Method.set_property=allow-none)
  * @self: a squeezer
  * @allow_none: whether @self allows squeezing beyond the last child
  *
@@ -1603,7 +1611,7 @@ adw_squeezer_set_allow_none (AdwSqueezer *self,
 }
 
 /**
- * adw_squeezer_get_transition_duration:
+ * adw_squeezer_get_transition_duration: (attributes org.gtk.Method.get_property=transition-duration)
  * @self: a squeezer
  *
  * Gets the transition animation duration for @self.
@@ -1621,7 +1629,7 @@ adw_squeezer_get_transition_duration (AdwSqueezer *self)
 }
 
 /**
- * adw_squeezer_set_transition_duration:
+ * adw_squeezer_set_transition_duration: (attributes org.gtk.Method.set_property=transition-duration)
  * @self: a squeezer
  * @duration: the new duration, in milliseconds
  *
@@ -1644,7 +1652,7 @@ adw_squeezer_set_transition_duration (AdwSqueezer *self,
 }
 
 /**
- * adw_squeezer_get_transition_type:
+ * adw_squeezer_get_transition_type: (attributes org.gtk.Method.get_property=transition-type)
  * @self: a squeezer
  *
  * Gets the type of animation used for transitions between children in @self.
@@ -1662,7 +1670,7 @@ adw_squeezer_get_transition_type (AdwSqueezer *self)
 }
 
 /**
- * adw_squeezer_set_transition_type:
+ * adw_squeezer_set_transition_type: (attributes org.gtk.Method.set_property=transition-type)
  * @self: a squeezer
  * @transition: the new transition type
  *
@@ -1684,7 +1692,7 @@ adw_squeezer_set_transition_type (AdwSqueezer               *self,
 }
 
 /**
- * adw_squeezer_get_transition_running:
+ * adw_squeezer_get_transition_running: (attributes org.gtk.Method.get_property=transition-running)
  * @self: a squeezer
  *
  * Gets whether a transition is currently running for @self.
@@ -1706,7 +1714,7 @@ adw_squeezer_get_transition_running (AdwSqueezer *self)
 }
 
 /**
- * adw_squeezer_get_interpolate_size:
+ * adw_squeezer_get_interpolate_size: (attributes org.gtk.Method.get_property=interpolate-size)
  * @self: A squeezer
  *
  * Gets whether @self interpolates its size when changing the visible child.
@@ -1724,7 +1732,7 @@ adw_squeezer_get_interpolate_size (AdwSqueezer *self)
 }
 
 /**
- * adw_squeezer_set_interpolate_size:
+ * adw_squeezer_set_interpolate_size: (attributes org.gtk.Method.set_property=interpolate-size)
  * @self: A squeezer
  * @interpolate_size: whether to interpolate the size
  *
@@ -1753,7 +1761,7 @@ adw_squeezer_set_interpolate_size (AdwSqueezer *self,
 }
 
 /**
- * adw_squeezer_get_xalign:
+ * adw_squeezer_get_xalign: (attributes org.gtk.Method.get_property=xalign)
  * @self: a squeezer
  *
  * Gets the horizontal alignment, from 0 (start) to 1 (end).
@@ -1771,7 +1779,7 @@ adw_squeezer_get_xalign (AdwSqueezer *self)
 }
 
 /**
- * adw_squeezer_set_xalign:
+ * adw_squeezer_set_xalign: (attributes org.gtk.Method.set_property=xalign)
  * @self: a squeezer
  * @xalign: the new alignment value
  *
@@ -1802,7 +1810,7 @@ adw_squeezer_set_xalign (AdwSqueezer *self,
 }
 
 /**
- * adw_squeezer_get_yalign:
+ * adw_squeezer_get_yalign: (attributes org.gtk.Method.get_property=yalign)
  * @self: a squeezer
  *
  * Gets the vertical alignment, from 0 (top) to 1 (bottom).
@@ -1820,7 +1828,7 @@ adw_squeezer_get_yalign (AdwSqueezer *self)
 }
 
 /**
- * adw_squeezer_set_yalign:
+ * adw_squeezer_set_yalign: (attributes org.gtk.Method.set_property=yalign)
  * @self: a squeezer
  * @yalign: the new alignment value
  *
@@ -1851,7 +1859,7 @@ adw_squeezer_set_yalign (AdwSqueezer *self,
 }
 
 /**
- * adw_squeezer_get_pages:
+ * adw_squeezer_get_pages: (attributes org.gtk.Method.get_property=pages)
  * @self: a squeezer
  *
  * Returns a [iface@Gio.ListModel] that contains the pages of @self.
@@ -1871,8 +1879,8 @@ adw_squeezer_get_pages (AdwSqueezer *self)
   if (self->pages)
     return g_object_ref (self->pages);
 
-  g_set_weak_pointer (&self->pages,
-                      GTK_SELECTION_MODEL (adw_squeezer_pages_new (self)));
+  self->pages = GTK_SELECTION_MODEL (adw_squeezer_pages_new (self));
+  g_object_add_weak_pointer (G_OBJECT (self->pages), (gpointer *) &self->pages);
 
   return self->pages;
 }
